%% Load data 
load('Figure2_Data.mat');
chAHA = 1; chSE = 2; chDNA = 3;

% Parse data by cell cycle stage (according to DNA)
[statTab, ResultTable] = cellCycleGroup(ResultTable, false);
% Clean data by DNA
ResultTable=ResultTable(ResultTable.idxcc~=0,:); %remove extreme outliers %ResultTable.NInt(:,chDNA)>3.8e5&ResultTable.NInt(:,chDNA)<10e5

% normalize size & AHA by mean of DMSO G1
normSize = mean(statTab.MedianSize(statTab.Condition=='DMSO', 2));
normAHA = mean(statTab.MedianIF(statTab.Condition=='DMSO', 2));
ResultTable.CInt(:,chSE) = ResultTable.CInt(:,chSE)/normSize;
ResultTable.CInt(:,chAHA) = ResultTable.CInt(:,chAHA)/normAHA;

% Parse data again by cell cycle stage (according to DNA)
[statTab, ResultTable] = cellCycleGroup(ResultTable, true);

%% PLOT - Size vs AHA at single cell level
% treatment conditions
idxDMSO = ResultTable.Condition=="DMSO"; 
idxCHX = ResultTable.Condition=="CHX"; % Cycloheximide, 3uM
idxSNS = ResultTable.Condition=="SNS"; % SNS-032, 25nM
idxPal =  ResultTable.Condition=="Pal"; % Palbociclib, 50nM
% {'DMSO','CHX','SB','Torin','SNS', 'Pal'};

% AHA vs. size scatterplot
figure(10); clf; xrange = [0 5.5];
scatter(ResultTable.CInt(idxCHX, chSE), ResultTable.CInt(idxCHX,chAHA), 1, [1 1 1]*.7, 'filled', 'MarkerFaceAlpha', .1,'HandleVisibility','off'); hold on
fitobj = fit(ResultTable.CInt(idxCHX, chSE), ResultTable.CInt(idxCHX,chAHA), 'poly1');
plot(xrange, fitobj.p1*xrange+fitobj.p2,'-', 'LineWidth',.5,'Color',[0 0 0], 'HandleVisibility','off')
scatter(ResultTable.CInt(idxSNS, chSE), ResultTable.CInt(idxSNS,chAHA), 1,  [.7 .2 .2], 'filled', 'MarkerFaceAlpha', .1,'HandleVisibility','off'); hold on
scatter(ResultTable.CInt(idxPal, chSE), ResultTable.CInt(idxPal,chAHA), 1, [.3 .2 0], 'filled', 'MarkerFaceAlpha', .1,'HandleVisibility','off'); hold on
scatter(ResultTable.CInt(idxDMSO, chSE), ResultTable.CInt(idxDMSO,chAHA), 1, [0 .5 .7], 'filled', 'MarkerFaceAlpha', .1,'HandleVisibility','off'); hold on
fitobj = fit(ResultTable.CInt(idxDMSO, chSE), ResultTable.CInt(idxDMSO,chAHA), 'poly1');
plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off')
xlabel('Cell Size (a.u.)'); ylabel('AHA incorporation (a.u.)'); set(gca,'fontsize',14); 
xlim([0 5.5]); ylim([0 5.5]); xticks(0:5.5); yticks(0:5.5); box on
% exportgraphics(gca, 'size_vs_AHA.jpg', 'Resolution', 600) % axis off & no fit line

figure(8); clf; hold on
histogram(ResultTable.CInt(idxCHX, chSE), 0:0.1:5.5, 'FaceColor', [1 1 1]*.7, 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxSNS, chSE), 0:0.1:5.5, 'FaceColor',  [.7 .2 .2], 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxPal, chSE), 0:0.1:5.5, 'FaceColor',  [.3 .2 0], 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxDMSO, chSE), 0:0.1:5.5, 'FaceColor', [0 .5 .7], 'Normalization', 'pdf')
title('cell size'); xlim([0 5.5]); xticks(0:1:5.5); 

figure(9); clf; hold on
histogram(ResultTable.CInt(idxCHX, chAHA), 0:.1:5.5, 'FaceColor', [1 1 1]*.7, 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxSNS, chAHA), 0:.1:5.5, 'FaceColor',  [.7 .2 .2], 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxPal, chAHA), 0:.1:5.5, 'FaceColor',  [.3 .2 0], 'Normalization', 'pdf')
histogram(ResultTable.CInt(idxDMSO, chAHA), 0:.1:5.5, 'FaceColor', [0 .5 .7], 'Normalization', 'pdf')
title('AHA incorporation'); xlim([0 5.5]); xticks(0:1:5.5);

% plot cell size range - for responding reviewer
figure; hold on 
histogram(ResultTable.CInt(idxDMSO, chSE), 0:.1:5.5, 'FaceColor', [0 .5 .7], 'Normalization', 'pdf')
plot([1;1]*prctile(ResultTable.CInt(idxDMSO, chSE),[1 50 99]), [0 1.5], 'k-');
title('cell size'); xlim([0 5.5]); xticks(0:5.5); ylim([0 1.5]); yticks(0:.5:1.5)

temp = ResultTable.NInt(:, chDNA)/mean(ResultTable.NInt(idxDMSO&ResultTable.idxcc==1, chDNA));
figure; hold on
histogram(temp(idxDMSO), 0:.01:3, 'Normalization', 'pdf');
plot([1; 1]*[.85 1.1 1.9 2.3],[0 10],'k')
title('DNA'); xlim([.5 2.5]); xticks(.5:.5:2.5); ylim([0 6]); yticks(0:2:6)
figure; hold on % for responding reviewer
for cc = 1:3
    [fi, xi] = ksdensity(ResultTable.CInt(idxDMSO&ResultTable.idxcc==cc, chSE), 0:.02:5.5, 'function', 'pdf');
    plot(xi,fi);
    plot([1;1]*median(ResultTable.CInt(idxDMSO&ResultTable.idxcc==cc, chSE)), [0 1.8], 'k-');
    disp(median(ResultTable.CInt(idxDMSO&ResultTable.idxcc==cc, chSE)))
end
title('cell size'); xlim([0 5.5]); xticks(0:5.5); ylim([0 1.8]); yticks(0:.5:1.5)

%% plot AHA vs. size separately for G1, S, G2
fitobj = fit(ResultTable.CInt(idxDMSO, chSE), ResultTable.CInt(idxDMSO,chAHA), 'poly1');
figure; clf; scatter(ResultTable.CInt(idxDMSO&ResultTable.idxcc==1, chSE), ResultTable.CInt(idxDMSO&ResultTable.idxcc==1,chAHA), 1, [0 .5 .7],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off')
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('G1','location','southeast') 
figure; clf; scatter(ResultTable.CInt(idxDMSO&ResultTable.idxcc==2, chSE), ResultTable.CInt(idxDMSO&ResultTable.idxcc==2, chAHA), 1, [0 .5 .7],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off')
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('S','location','southeast') 
figure; clf; scatter(ResultTable.CInt(idxDMSO&ResultTable.idxcc==3, chSE), ResultTable.CInt(idxDMSO&ResultTable.idxcc==3, chAHA), 1, [0 .5 .7],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off')
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('G2','location','southeast') 

figure; clf; scatter(ResultTable.CInt(idxSNS&ResultTable.idxcc==1, chSE), ResultTable.CInt(idxSNS&ResultTable.idxcc==1,chAHA), 1, [.7 .2 .2],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off'); 
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('G1','location','southeast') 
figure; clf; scatter(ResultTable.CInt(idxSNS&ResultTable.idxcc==2, chSE), ResultTable.CInt(idxSNS&ResultTable.idxcc==2, chAHA), 1, [.7 .2 .2],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off'); 
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('S','location','southeast') 
figure; clf; scatter(ResultTable.CInt(idxSNS&ResultTable.idxcc==3, chSE), ResultTable.CInt(idxSNS&ResultTable.idxcc==3, chAHA), 1, [.7 .2 .2],'filled', 'MarkerFaceAlpha',.2); 
hold on; plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[0 0 0], 'LineWidth',.5,'HandleVisibility','off'); 
axis([0.5e6/normSize 1.2e7/normSize 0 4e7/normAHA]); box on; set(gca,'xtick',1:5,'ytick',0:5,'fontsize',14);legend('G2','location','southeast') 

%% plot cell cycle averages - median
idxxDMSO = statTab.Condition=="DMSO"; 
idxxCHX = statTab.Condition=="CHX";
idxxSNS = statTab.Condition=="SNS";  
idxxPal = statTab.Condition=="Pal"; 
statTab.MedianSizeNorm = statTab.MedianSize/mean(statTab.MedianSize(idxxDMSO, 2));
statTab.MedianAHANorm = statTab.MedianIF/mean(statTab.MedianIF(idxxDMSO, 2));

figure; clf; hold on
markers = ["o" "d" "s"];
% CHX
for idxcc = 2:4
    plot(statTab.MedianSizeNorm(idxxCHX, idxcc), statTab.MedianAHANorm(idxxCHX, idxcc), markers(idxcc-1), 'MarkerSize',4, 'Color', [1 1 1]*.7, 'LineWidth', .25) % G1
plot(median(statTab.MedianSizeNorm(idxxCHX, idxcc)), median(statTab.MedianAHANorm(idxxCHX, idxcc)), markers(idxcc-1), 'MarkerSize',9, 'Color', [1 1 1]*.7, 'LineWidth', .4) 
errorbar(median(statTab.MedianSizeNorm(idxxCHX, idxcc)), median(statTab.MedianAHANorm(idxxCHX, idxcc)), tinv(.9725, sum(idxxCHX)-1)*std(statTab.MedianAHANorm(idxxCHX, idxcc))/sqrt(sum(idxxCHX)), tinv(.9725, sum(idxxCHX)-1)*std(statTab.MedianAHANorm(idxxCHX, idxcc))/sqrt(sum(idxxCHX)), ...
    tinv(.9725, sum(idxxCHX)-1)*std(statTab.MedianSizeNorm(idxxCHX, idxcc))/sqrt(sum(idxxCHX)), tinv(.9725, sum(idxxCHX)-1)*std(statTab.MedianSizeNorm(idxxCHX, idxcc))/sqrt(sum(idxxCHX)), 'Color', [1 1 1]*.7, 'LineWidth', 1) % G1
end

% SNS
for idxcc = 2:4
    plot(statTab.MedianSizeNorm(idxxSNS, idxcc), statTab.MedianAHANorm(idxxSNS, idxcc), markers(idxcc-1), 'MarkerSize',4, 'Color', [.7 .2 .2], 'LineWidth', .25) % G1
plot(median(statTab.MedianSizeNorm(idxxSNS, idxcc)), median(statTab.MedianAHANorm(idxxSNS, idxcc)), markers(idxcc-1), 'MarkerSize',9, 'Color', [.7 .2 .2], 'LineWidth', .4) 
errorbar(median(statTab.MedianSizeNorm(idxxSNS, idxcc)), median(statTab.MedianAHANorm(idxxSNS, idxcc)), tinv(.9725, sum(idxxSNS)-1)*std(statTab.MedianAHANorm(idxxSNS, idxcc))/sqrt(sum(idxxSNS)), tinv(.9725, sum(idxxSNS)-1)*std(statTab.MedianAHANorm(idxxSNS, idxcc))/sqrt(sum(idxxSNS)), ...
    tinv(.9725, sum(idxxSNS)-1)*std(statTab.MedianSizeNorm(idxxSNS, idxcc))/sqrt(sum(idxxSNS)), tinv(.9725, sum(idxxSNS)-1)*std(statTab.MedianSizeNorm(idxxSNS, idxcc))/sqrt(sum(idxxSNS)), 'Color', [.7 .2 .2], 'LineWidth', 1) % G1
end

% Palbo
for idxcc = 2:4
    plot(statTab.MedianSizeNorm(idxxPal, idxcc), statTab.MedianAHANorm(idxxPal, idxcc), markers(idxcc-1), 'MarkerSize',4, 'Color', [.3 .2 0], 'LineWidth', .25) % G1
plot(median(statTab.MedianSizeNorm(idxxPal, idxcc)), median(statTab.MedianAHANorm(idxxPal, idxcc)), markers(idxcc-1), 'MarkerSize',9, 'Color', [.3 .2 0], 'LineWidth', .4) 
errorbar(median(statTab.MedianSizeNorm(idxxPal, idxcc)), median(statTab.MedianAHANorm(idxxPal, idxcc)), tinv(.9725, sum(idxxPal)-1)*std(statTab.MedianAHANorm(idxxPal, idxcc))/sqrt(sum(idxxPal)), tinv(.9725, sum(idxxPal)-1)*std(statTab.MedianAHANorm(idxxPal, idxcc))/sqrt(sum(idxxPal)), ...
    tinv(.9725, sum(idxxPal)-1)*std(statTab.MedianSizeNorm(idxxPal, idxcc))/sqrt(sum(idxxPal)), tinv(.9725, sum(idxxPal)-1)*std(statTab.MedianSizeNorm(idxxPal, idxcc))/sqrt(sum(idxxPal)), 'Color', [.3 .2 0], 'LineWidth', 1) % G1
end

% DMSO
for idxcc = 2:4
    plot(statTab.MedianSizeNorm(idxxDMSO, idxcc), statTab.MedianAHANorm(idxxDMSO, idxcc), markers(idxcc-1), 'MarkerSize',4, 'Color', [0 .5 .7], 'LineWidth', .25) % G1
plot(median(statTab.MedianSizeNorm(idxxDMSO, idxcc)), median(statTab.MedianAHANorm(idxxDMSO, idxcc)), markers(idxcc-1), 'MarkerSize',9, 'Color', [0 .5 .7], 'LineWidth', .4) 
errorbar(median(statTab.MedianSizeNorm(idxxDMSO, idxcc)), median(statTab.MedianAHANorm(idxxDMSO, idxcc)), tinv(.9725, sum(idxxDMSO)-1)*std(statTab.MedianAHANorm(idxxDMSO, idxcc))/sqrt(sum(idxxDMSO)), tinv(.9725, sum(idxxDMSO)-1)*std(statTab.MedianAHANorm(idxxDMSO, idxcc))/sqrt(sum(idxxDMSO)), ...
    tinv(.9725, sum(idxxDMSO)-1)*std(statTab.MedianSizeNorm(idxxDMSO, idxcc))/sqrt(sum(idxxDMSO)), tinv(.9725, sum(idxxDMSO)-1)*std(statTab.MedianSizeNorm(idxxDMSO, idxcc))/sqrt(sum(idxxDMSO)), 'Color', [0 .5 .7], 'LineWidth', 1) % G1
end

xx = statTab.MedianSizeNorm(idxxDMSO|idxxSNS|idxxPal, 2:4);
yy = statTab.MedianAHANorm(idxxDMSO|idxxSNS|idxxPal, 2:4);
xrange = [0 2.5];
fitobj = fit(xx(:), yy(:), 'poly1');
plot(xrange, fitobj.p1*xrange+fitobj.p2,'-','color',[1 1 1]*0.3, 'LineWidth',.5,'HandleVisibility','off')
xlabel('Cell Size (a.u.)'); ylabel('AHA incorporation (a.u.)'); xlim([0.75 2.5]); ylim([0 2.5]); set(gca,'fontsize',14)