load('Figure3BCD_Data.mat')

%% Reorganize data by treatments
Tt = [1 8 24]; 
cellcycle = ["All cells" "G1" "G1S" "S" "G2+M"];

conditions = table; 
conditions.Drug = ["DMSO"; "SNS";"PAL"];
NN = size(conditions,1); Nt = length(Tt);
conditions.deltaIF = cell(NN,Nt); % conditions by timepoints
conditions.deltaIF_mean = nan(NN,length(cellcycle),Nt);
conditions.deltaIF_CI = nan(NN,length(cellcycle),Nt);
conditions.cellsize = cell(NN,Nt);
conditions.cellsize_mean = nan(NN,length(cellcycle),Nt);
conditions.cellsize_CI = nan(NN,length(cellcycle),Nt);
conditions.cellnum = cell(NN,Nt);

conditions.ccfrac_mean = nan(NN,length(cellcycle)-1,Nt);
conditions.ccfrac_CI = nan(NN,length(cellcycle)-1,Nt);
conditions.ccfrac = cell(NN,Nt);

for nt = 1:Nt
    for nn = 1:NN
        temp = statTab(statTab.Drug==conditions.Drug(nn) & statTab.DrugTime==Tt(nt) & statTab.AbAdded==1,:);
        idx = temp.CFZ==1;
        % calculate delta_K48 by substracting CFZ+ & CFZ-
        nrep = size(temp,1); %nrep = sum(idx);
        temp1IF = temp.MedianIF(idx,1:end-1); temp2IF = temp.MedianIF(~idx,1:end-1); 
        temp1size = temp.MedianSize(idx,1:end-1); temp2size = temp.MedianSize(~idx,1:end-1);
%         conditions.deltaIF{nn, nt} = temp1IF-temp2IF;
%         conditions.cellsize{nn, nt} = temp1size; %(temp1size+temp2size)/2;
        for cc = 1:length(cellcycle)
            temp1c = repmat(temp1IF(:,cc), nrep, 1);
            temp2c = repmat(temp2IF(:,cc), 1, nrep); temp2c = temp2c'; temp2c = temp2c(:);
            conditions.deltaIF{nn, nt}(:,cc) = temp1c-temp2c;
            temp1c = repmat(temp1size(:,cc), nrep, 1);
            temp2c = repmat(temp2size(:,cc), 1, nrep); temp2c = temp2c'; temp2c = temp2c(:);
            conditions.cellsize{nn, nt}(:,cc) = (temp1c+temp2c)/2;
        end
        conditions.deltaIF_mean(nn,:,nt) = mean(conditions.deltaIF{nn, nt}); 
        conditions.deltaIF_CI(nn,:, nt) = tinv(.975, nrep-1)*std(conditions.deltaIF{nn, nt})/sqrt(nrep);%95% confidence interval range
        
        conditions.cellsize_mean(nn,:,nt) = mean(conditions.cellsize{nn, nt});
        nrep = size(conditions.cellsize{nn, nt},1);
        conditions.cellsize_CI(nn,:, nt) = tinv(.975, nrep-1)*std(conditions.cellsize{nn, nt})/sqrt(nrep); %95% confidence interval range
        
        conditions.cellnum{nn, nt} = temp.CellNum(:,1); 
        
        conditions.ccfrac{nn, nt} = temp.Props; 
        conditions.ccfrac_mean(nn,:,nt) = mean(conditions.ccfrac{nn, nt});
        conditions.ccfrac_CI(nn,:,nt) = std(conditions.ccfrac{nn, nt})/sqrt(size(temp,1))*tinv(0.975, size(temp,1)-1);
    end
    normFactorIF = mean(conditions.deltaIF{1, nt}(:,2)); % G1 of controls
    normFactorCellSize = mean(conditions.cellsize{1, nt}(:,2)); % G1 of controls
    
    conditions.deltaIF_mean(:,:, nt) = conditions.deltaIF_mean(:,:, nt)/normFactorIF;
    conditions.deltaIF_CI(:,:, nt) = conditions.deltaIF_CI(:,:, nt)/normFactorIF;
    conditions.cellsize_mean(:,:, nt) = conditions.cellsize_mean(:,:, nt)/normFactorCellSize;
    conditions.cellsize_CI(:,:, nt) = conditions.cellsize_CI(:,:, nt)/normFactorCellSize;
    for nn = 1:NN
        conditions.deltaIF{nn, nt} = conditions.deltaIF{nn, nt}/normFactorIF;
        conditions.cellsize{nn, nt} = conditions.cellsize{nn, nt}/normFactorCellSize;
    end
end

clear ans idx nn nt nrep temp temp1 temp2 normFactorCellSize normFactorIF temp1c temp2c  temp1IF temp2IF temp1size temp2size

%% size vs delta-K48
shape = ["o" "v" "d" "s"];
nt = 3; % 24h
nd = 2; % SNS
figure; hold on
for cc =  [2 4 5]%2:length(cellcycle) %
    scatter(conditions.cellsize{1,nt}(:,cc),conditions.deltaIF{1,nt}(:,cc), 3, 'b','filled','MarkerFaceAlpha',.5);
    scatter(conditions.cellsize{nd,nt}(:,cc),conditions.deltaIF{nd,nt}(:,cc), 3, 'r','filled','MarkerFaceAlpha',.5);
    errorbar(conditions.cellsize_mean(1,cc,nt),conditions.deltaIF_mean(1,cc,nt), conditions.deltaIF_CI(1,cc,nt), conditions.deltaIF_CI(1,cc,nt), ...
        conditions.cellsize_CI(1,cc,nt), conditions.cellsize_CI(1,cc,nt), shape(cc-1), 'Color','b');
    errorbar(conditions.cellsize_mean(nd,cc,nt),conditions.deltaIF_mean(nd,cc,nt), conditions.deltaIF_CI(nd,cc,nt), conditions.deltaIF_CI(nd,cc,nt), ...
        conditions.cellsize_CI(nd,cc,nt), conditions.cellsize_CI(nd,cc,nt), shape(cc-1), 'Color','r');
end
plot([0 4], [0 4], 'k');  axis equal;
if nd ==2
    xlim([.75 2.1]); ylim([.75 2.3])
else
    xlim([.75 2.7]); ylim([.75 3.1]); %xlim([.75 2.5]); ylim([.75 3])
end
xlabel('Cell Size'); ylabel('delta-K48 polyUb'); title(conditions.Drug(nd)+", "+Tt(nt)+"h");

% calculate statistical significance
for cc = 2:5
    [~, pval] = ttest2(conditions.deltaIF{1,nt}(:,cc),conditions.deltaIF{2,nt}(:,cc), 'Tail', 'left');
    disp(cellcycle(cc)); disp(pval)
end

%% over time
nd = 2; % SNS
% size
figure; hold on
for nt = 1:Nt
    temp = conditions.cellsize{1,nt}(:,1);
    scatter(Tt(nt)+randn(length(temp),1)*0.1, conditions.cellsize{1,nt}(:,1), 3, 'b', 'filled', 'MarkerFaceAlpha', .5)
    temp = conditions.cellsize{nd,nt}(:,1);
    scatter(Tt(nt)+randn(length(temp),1)*0.1, conditions.cellsize{nd,nt}(:,1), 3, 'r', 'filled', 'MarkerFaceAlpha', .5)
end
errorbar(Tt, reshape(conditions.cellsize_mean(1,1,:),Nt,1), reshape(conditions.cellsize_CI(1,1,:),Nt,1), 'bo-')
errorbar(Tt, reshape(conditions.cellsize_mean(nd,1,:),Nt,1), reshape(conditions.cellsize_CI(nd,1,:),Nt,1), 'ro-')
title("All, "+conditions.Drug(nd)); xlim([-1 25]); ylim([0.79 2.3]);
xlabel('Time (hr)'); ylabel('Cell Size (a.u.)');

% delta_K48
for cc = [1 2 4 5]
    figure; hold on
    for nt = 1:Nt
        temp = conditions.deltaIF{1,nt}(:,cc);
        scatter(Tt(nt)+randn(length(temp),1)*0.1, conditions.deltaIF{1,nt}(:,cc), 3, 'b', 'filled', 'MarkerFaceAlpha', .5)
        temp = conditions.deltaIF{nd,nt}(:,cc);
        scatter(Tt(nt)+randn(length(temp),1)*0.1, conditions.deltaIF{nd,nt}(:,cc), 3, 'r', 'filled', 'MarkerFaceAlpha', .5)
    end
    errorbar(Tt, reshape(conditions.deltaIF_mean(1,cc,:),Nt,1), reshape(conditions.deltaIF_CI(1,cc,:),Nt,1), 'bo-')
    errorbar(Tt, reshape(conditions.deltaIF_mean(nd,cc,:),Nt,1), reshape(conditions.deltaIF_CI(nd,cc,:),Nt,1), 'ro-')
    title(cellcycle(cc)+", "+conditions.Drug(nd)); xlim([-.2 25]);
    if cc>1; ylim([0.78 2.21]); else; ylim([1 1.8]); end
    xlabel('Time (hr)'); ylabel('delta-K48 polyUb');
end
%% over cell cycle
% figure; hold on
% for cc = 2:length(cellcycle)
%     temp = conditions.cellsize{1,3}(:,cc);
%     scatter(cc+randn(length(temp),1)*0.05, temp, 3, 'b', 'filled', 'MarkerFaceAlpha', .5)
%     temp = conditions.cellsize{2,3}(:,cc);
%     scatter(cc+randn(length(temp),1)*0.05, temp, 3, 'r', 'filled', 'MarkerFaceAlpha', .5)
% end
% errorbar(2:length(cellcycle), conditions.cellsize_mean(1,2:5,3), conditions.cellsize_CI(1,2:5,3), 'bs')
% errorbar(2:length(cellcycle), conditions.cellsize_mean(2,2:5,3), conditions.cellsize_CI(2,2:5,3), 'rs')
% fitobj = fit([2 4 5]', conditions.cellsize_mean(1,[2 4 5],3)','poly1');
% plot([1.8 5.2], fitobj.p1*[1.8 5.2]+fitobj.p2,'k')
% fitobj = fit([2 4 5]', conditions.cellsize_mean(2,[2 4 5],3)','poly1');
% plot([1.8 5.2], fitobj.p1*[1.8 5.2]+fitobj.p2,'k')
% title("24h"); xlim([1.5 5.5]); ylim([0.9 1.9]);
% xticks(2:length(cellcycle)); xticklabels(cellcycle(2:end)); 
% ylabel('Cell Size (a.u.)');
% 
% 
% figure; hold on
% for cc = 2:length(cellcycle)
%     temp = conditions.deltaIF{1,3}(:,cc);
%     scatter(cc+randn(length(temp),1)*0.05, temp, 3, 'b', 'filled', 'MarkerFaceAlpha', .5)
%     temp = conditions.deltaIF{2,3}(:,cc);
%     scatter(cc+randn(length(temp),1)*0.05, temp, 3, 'r', 'filled', 'MarkerFaceAlpha', .5)
% end
% errorbar(2:length(cellcycle), conditions.deltaIF_mean(1,2:5,3), conditions.deltaIF_CI(1,2:5,3), 'bs')
% errorbar(2:length(cellcycle), conditions.deltaIF_mean(2,2:5,3), conditions.deltaIF_CI(2,2:5,3), 'rs')
% fitobj = fit([2 4 5]', conditions.deltaIF_mean(1,[2 4 5],3)','poly1');
% plot([1.8 5.2], fitobj.p1*[1.8 5.2]+fitobj.p2,'k')
% fitobj = fit([2 4 5]', conditions.deltaIF_mean(2,[2 4 5],3)','poly1');
% plot([1.8 5.2], fitobj.p1*[1.8 5.2]+fitobj.p2,'k')
% title("24h"); xlim([1.5 5.5]); ylim([0.8 2.3]);
% xticks(2:length(cellcycle)); xticklabels(cellcycle(2:end)); 
% ylabel('delta-K48 polyUb');



