load('Figure3BCD_Data.mat')

%% Reorganize data by treatments
Tt = [1 8 24]; 
cellcycle = ["All cells" "G1" "G1S" "S" "G2+M"];

conditions = table; 
conditions.Drug = ["DMSO"; "SNS";"PAL"];
NN = size(conditions,1); Nt = length(Tt);
conditions.deltaIF = cell(NN,Nt); % conditions by timepoints
conditions.deltaIF_mean = nan(NN,length(cellcycle),Nt);
conditions.deltaIF_CI = nan(NN,length(cellcycle),Nt);
conditions.cellsize = cell(NN,Nt);
conditions.cellsize_mean = nan(NN,length(cellcycle),Nt);
conditions.cellsize_CI = nan(NN,length(cellcycle),Nt);
conditions.cellnum = cell(NN,Nt);

conditions.ccfrac_mean = nan(NN,length(cellcycle)-1,Nt);
conditions.ccfrac_CI = nan(NN,length(cellcycle)-1,Nt);
conditions.ccfrac = cell(NN,Nt);

for nt = 1:Nt
    for nn = 1:NN
        temp = statTab(statTab.Drug==conditions.Drug(nn) & statTab.DrugTime==Tt(nt) & statTab.AbAdded==1,:);
        idx = temp.CFZ==1;
        % calculate delta_K48 by substracting CFZ+ & CFZ-
        nrep = size(temp,1); %nrep = sum(idx);
        temp1IF = temp.MedianIF(idx,1:end-1); temp2IF = temp.MedianIF(~idx,1:end-1); 
        temp1size = temp.MedianSize(idx,1:end-1); temp2size = temp.MedianSize(~idx,1:end-1);
%         conditions.deltaIF{nn, nt} = temp1IF-temp2IF;
%         conditions.cellsize{nn, nt} = temp1size; %(temp1size+temp2size)/2;
        for cc = 1:length(cellcycle)
            temp1c = repmat(temp1IF(:,cc), nrep, 1);
            temp2c = repmat(temp2IF(:,cc), 1, nrep); temp2c = temp2c'; temp2c = temp2c(:);
            conditions.deltaIF{nn, nt}(:,cc) = temp1c-temp2c;
            temp1c = repmat(temp1size(:,cc), nrep, 1);
            temp2c = repmat(temp2size(:,cc), 1, nrep); temp2c = temp2c'; temp2c = temp2c(:);
            conditions.cellsize{nn, nt}(:,cc) = (temp1c+temp2c)/2;
        end
        conditions.deltaIF_mean(nn,:,nt) = mean(conditions.deltaIF{nn, nt}); 
        conditions.deltaIF_CI(nn,:, nt) = tinv(.975, nrep-1)*std(conditions.deltaIF{nn, nt})/sqrt(nrep);%95% confidence interval range
        
        conditions.cellsize_mean(nn,:,nt) = mean(conditions.cellsize{nn, nt});
        nrep = size(conditions.cellsize{nn, nt},1);
        conditions.cellsize_CI(nn,:, nt) = tinv(.975, nrep-1)*std(conditions.cellsize{nn, nt})/sqrt(nrep); %95% confidence interval range
        
        conditions.cellnum{nn, nt} = temp.CellNum(:,1); 
        
        conditions.ccfrac{nn, nt} = temp.Props; 
        conditions.ccfrac_mean(nn,:,nt) = mean(conditions.ccfrac{nn, nt});
        conditions.ccfrac_CI(nn,:,nt) = std(conditions.ccfrac{nn, nt})/sqrt(size(temp,1))*tinv(0.975, size(temp,1)-1);
    end
    normFactorIF = mean(conditions.deltaIF{1, nt}(:,2)); % G1 of controls
    normFactorCellSize = mean(conditions.cellsize{1, nt}(:,2)); % G1 of controls
    
    conditions.deltaIF_mean(:,:, nt) = conditions.deltaIF_mean(:,:, nt)/normFactorIF;
    conditions.deltaIF_CI(:,:, nt) = conditions.deltaIF_CI(:,:, nt)/normFactorIF;
    conditions.cellsize_mean(:,:, nt) = conditions.cellsize_mean(:,:, nt)/normFactorCellSize;
    conditions.cellsize_CI(:,:, nt) = conditions.cellsize_CI(:,:, nt)/normFactorCellSize;
    for nn = 1:NN
        conditions.deltaIF{nn, nt} = conditions.deltaIF{nn, nt}/normFactorIF;
        conditions.cellsize{nn, nt} = conditions.cellsize{nn, nt}/normFactorCellSize;
    end
end

clear ans idx nn nt nrep temp temp1 temp2 normFactorCellSize normFactorIF temp1c temp2c  temp1IF temp2IF temp1size temp2size

%% cell cycle fractions
% % bar plot
% for nt = 1:Nt
%     figure; hold on
%     bar(1:NN, conditions.ccfrac_mean(:,:,nt), 'stacked');
%     for cc = 1:length(cellcycle)-1
%         errorbar(1:NN, sum(conditions.ccfrac_mean(:,1:cc,nt),2), conditions.ccfrac_CI(:,cc,nt), 'k.');
%     end
% 	ylim([0 1]); ylabel('Proportion'); xticks(1:NN); xticklabels(conditions.Drug)
%     title(Tt(nt)+"h"); box off
% end

% show only the affected cell cycle
nn = conditions.Drug=="PAL";
cc = 1;
figure; hold on
temp = conditions.ccfrac_mean(1,cc,:); temp_CI = conditions.ccfrac_CI(1,cc,:); temp = temp(:); temp_CI = temp_CI(:);
bar([1 3], temp([2 3]), 'BarWidth', .25); errorbar([1 3], temp([2 3]), temp_CI([2 3]),'k.');
temp = conditions.ccfrac_mean(nn,cc,:); temp_CI = conditions.ccfrac_CI(nn,cc,:); temp = temp(:); temp_CI = temp_CI(:);
bar([2 4], temp([2 3]), 'BarWidth', .25); errorbar([2 4], temp([2 3]), temp_CI([2 3]),'k.');
len = size(conditions.ccfrac{1,1}(:,cc),1);
scatter(1+randn(len,1)*0.1, conditions.ccfrac{1,2}(:,cc), 6, 'b', 'filled', 'MarkerFaceAlpha',.5)
scatter(3+randn(len,1)*0.1, conditions.ccfrac{1,3}(:,cc), 6, 'b', 'filled', 'MarkerFaceAlpha',.5)
len = size(conditions.ccfrac{3,1}(:,cc),1);
scatter(2+randn(len,1)*0.1, conditions.ccfrac{3,2}(:,cc), 6, 'r', 'filled', 'MarkerFaceAlpha',.5)
scatter(4+randn(len,1)*0.1, conditions.ccfrac{3,3}(:,cc), 6, 'r', 'filled', 'MarkerFaceAlpha',.5)
ylim([0 .9]); ylabel('G1 proportion'); 
xticks(1:4); xticklabels(["DMSO, 8h" "PAL, 8h" "DMSO, 24h" "PAL, 24h"])
[~, pval] = ttest2(conditions.ccfrac{1,2}(:,cc), conditions.ccfrac{nn,2}(:,cc));
disp("DMSO vs. PAL, 8h, G1 proportions, pval = "+num2str(pval, '%.1e'))
[~, pval] = ttest2(conditions.ccfrac{1,3}(:,cc), conditions.ccfrac{nn,3}(:,cc));
disp("DMSO vs. PAL, 24h, G1 proportions, pval = "+num2str(pval, '%.1e'))

%% size vs delta-K48
shape = ["o" "v" "d" "s"];
nd = 3; % PAL
for nt = 2:3
    figure; hold on
    for cc =  [2 4 5]%2:length(cellcycle) %
        scatter(conditions.cellsize{1,nt}(:,cc),conditions.deltaIF{1,nt}(:,cc), 3, 'b','filled','MarkerFaceAlpha',.5);
        scatter(conditions.cellsize{nd,nt}(:,cc),conditions.deltaIF{nd,nt}(:,cc), 3, 'r','filled','MarkerFaceAlpha',.5);
        errorbar(conditions.cellsize_mean(1,cc,nt),conditions.deltaIF_mean(1,cc,nt), conditions.deltaIF_CI(1,cc,nt), conditions.deltaIF_CI(1,cc,nt), ...
            conditions.cellsize_CI(1,cc,nt), conditions.cellsize_CI(1,cc,nt), shape(cc-1), 'Color','b');
        errorbar(conditions.cellsize_mean(nd,cc,nt),conditions.deltaIF_mean(nd,cc,nt), conditions.deltaIF_CI(nd,cc,nt), conditions.deltaIF_CI(nd,cc,nt), ...
            conditions.cellsize_CI(nd,cc,nt), conditions.cellsize_CI(nd,cc,nt), shape(cc-1), 'Color','r');
    end
    plot([0 4], [0 4], 'k');  axis equal; 
    if nd ==2
        xlim([.75 2.1]); ylim([.75 2.3])
    else
        xlim([.75 2.7]); ylim([.75 3.1]); %xlim([.75 2.5]); ylim([.75 3])
    end
    xlabel('Cell Size'); ylabel('delta-K48 polyUb'); title(conditions.Drug(nd)+", "+Tt(nt)+"h");
end
